@@ -10,12 +10,11 @@ fn is_not_hidden(entry: &DirEntry) -> bool {
         .unwrap_or(false)
 }
 
-pub fn collect_python_files(path: &PathBuf) -> Vec<DirEntry> {
+pub fn iter_python_files(path: &PathBuf) -> impl Iterator<Item = DirEntry> {
     WalkDir::new(path)
         .follow_links(true)
         .into_iter()
         .filter_entry(is_not_hidden)
         .filter_map(|entry| entry.ok())
         .filter(|entry| entry.path().to_string_lossy().ends_with(".py"))
-        .collect()
 }
