@@ -2,26 +2,12 @@ use std::path::Path;
 
 use anyhow::Result;
 use log::debug;
-use serde::{Deserialize, Serialize};
 
-use crate::cache::Mode;
 use crate::checker::check_ast;
 use crate::message::Message;
 use crate::{cache, parser};
 
-#[derive(Serialize, Deserialize)]
-struct CacheMetadata {
-    size: u64,
-    mtime: i64,
-}
-
-#[derive(Serialize, Deserialize)]
-struct CheckResult {
-    metadata: CacheMetadata,
-    messages: Vec<Message>,
-}
-
-pub fn check_path(path: &Path, mode: &Mode) -> Result<Vec<Message>> {
+pub fn check_path(path: &Path, mode: &cache::Mode) -> Result<Vec<Message>> {
     // Check the cache.
     if let Some(messages) = cache::get(path, mode) {
         debug!("Cache hit for: {}", path.to_string_lossy());
